==> zio-aws-ec2_2.12-6.20.78.1-sources.jar: zio/aws/ec2/model/DeleteTrafficMirrorTargetRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.TrafficMirrorTargetId
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteTrafficMirrorTargetRequest(
    trafficMirrorTargetId: TrafficMirrorTargetId
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeleteTrafficMirrorTargetRequest = {
    import DeleteTrafficMirrorTargetRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeleteTrafficMirrorTargetRequest
      .builder()
      .trafficMirrorTargetId(
        TrafficMirrorTargetId.unwrap(trafficMirrorTargetId): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DeleteTrafficMirrorTargetRequest.ReadOnly =
    zio.aws.ec2.model.DeleteTrafficMirrorTargetRequest.wrap(buildAwsValue())
}
object DeleteTrafficMirrorTargetRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeleteTrafficMirrorTargetRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DeleteTrafficMirrorTargetRequest =
      zio.aws.ec2.model.DeleteTrafficMirrorTargetRequest(trafficMirrorTargetId)
    def trafficMirrorTargetId: TrafficMirrorTargetId
    def getTrafficMirrorTargetId: ZIO[Any, Nothing, TrafficMirrorTargetId] =
      ZIO.succeed(trafficMirrorTargetId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeleteTrafficMirrorTargetRequest
  ) extends zio.aws.ec2.model.DeleteTrafficMirrorTargetRequest.ReadOnly {
    override val trafficMirrorTargetId: TrafficMirrorTargetId =
      zio.aws.ec2.model.primitives
        .TrafficMirrorTargetId(impl.trafficMirrorTargetId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeleteTrafficMirrorTargetRequest
  ): zio.aws.ec2.model.DeleteTrafficMirrorTargetRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.12-7.21.15.7-sources.jar: zio/aws/ec2/model/DeleteTrafficMirrorTargetRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.TrafficMirrorTargetId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteTrafficMirrorTargetRequest(
    trafficMirrorTargetId: TrafficMirrorTargetId,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeleteTrafficMirrorTargetRequest = {
    import DeleteTrafficMirrorTargetRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeleteTrafficMirrorTargetRequest
      .builder()
      .trafficMirrorTargetId(
        TrafficMirrorTargetId.unwrap(trafficMirrorTargetId): java.lang.String
      )
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DeleteTrafficMirrorTargetRequest.ReadOnly =
    zio.aws.ec2.model.DeleteTrafficMirrorTargetRequest.wrap(buildAwsValue())
}
object DeleteTrafficMirrorTargetRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeleteTrafficMirrorTargetRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DeleteTrafficMirrorTargetRequest =
      zio.aws.ec2.model.DeleteTrafficMirrorTargetRequest(
        trafficMirrorTargetId,
        dryRun.map(value => value)
      )
    def trafficMirrorTargetId: TrafficMirrorTargetId
    def dryRun: Optional[Boolean]
    def getTrafficMirrorTargetId: ZIO[Any, Nothing, TrafficMirrorTargetId] =
      ZIO.succeed(trafficMirrorTargetId)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeleteTrafficMirrorTargetRequest
  ) extends zio.aws.ec2.model.DeleteTrafficMirrorTargetRequest.ReadOnly {
    override val trafficMirrorTargetId: TrafficMirrorTargetId =
      zio.aws.ec2.model.primitives
        .TrafficMirrorTargetId(impl.trafficMirrorTargetId())
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeleteTrafficMirrorTargetRequest
  ): zio.aws.ec2.model.DeleteTrafficMirrorTargetRequest.ReadOnly = new Wrapper(
    impl
  )
}
